pub struct Bark { /* private fields */ }Implementations
Sourceimpl Bark
impl Bark
pub fn new() -> Self
pub fn born(timestamp: u64, token: String) -> Self
Sourcepub fn force_refresh_token(&mut self) -> (u64, String)
pub fn force_refresh_token(&mut self) -> (u64, String)
force refresh apns token
return (create_timestamp, token)
Sourcepub fn send<T>(&mut self, msg: &Msg, devices: T) -> Option<Vec<String>>where
T: IntoIterator<Item = String>,
pub fn send<T>(&mut self, msg: &Msg, devices: T) -> Option<Vec<String>>where
T: IntoIterator<Item = String>,
send msg to devices
return : None if success, or a vector of failed devices and error messages
Sourcepub async fn async_send<T>(
&mut self,
msg: &Msg,
devices: T,
) -> Option<Vec<String>>where
T: IntoIterator<Item = String>,
pub async fn async_send<T>(
&mut self,
msg: &Msg,
devices: T,
) -> Option<Vec<String>>where
T: IntoIterator<Item = String>,
async send to devices
return : None if success, or a vector of failed devices and error messages