pub enum Level {
ACTIVE,
TIMESENSITIVE,
PASSIVE,
}Expand description
Notification level
active: Default value, the system will immediately display the notification on the screen.
timeSensitive: Time-sensitive notification, can be displayed while in focus mode.
passive: Only adds the notification to the notification list, will not display on the screen.
Variants
Implementations